# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/raw_logs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/cdn/v1/raw_logs.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1dyandex/cloud/validation.proto\"v\n\x0fRawLogsSettings\x12#\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024\x12\x1f\n\rbucket_region\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\x0b\x66ile_prefix\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50*\xa4\x01\n\rRawLogsStatus\x12\x1f\n\x1bRAW_LOGS_STATUS_UNSPECIFIED\x10\x00\x12!\n\x1dRAW_LOGS_STATUS_NOT_ACTIVATED\x10\x01\x12\x16\n\x12RAW_LOGS_STATUS_OK\x10\x02\x12\x1a\n\x16RAW_LOGS_STATUS_FAILED\x10\x03\x12\x1b\n\x17RAW_LOGS_STATUS_PENDING\x10\x04\x42V\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.raw_logs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _RAWLOGSSETTINGS.fields_by_name['bucket_name']._options = None
  _RAWLOGSSETTINGS.fields_by_name['bucket_name']._serialized_options = b'\350\3071\001\212\3101\006<=1024'
  _RAWLOGSSETTINGS.fields_by_name['bucket_region']._options = None
  _RAWLOGSSETTINGS.fields_by_name['bucket_region']._serialized_options = b'\212\3101\004<=50'
  _RAWLOGSSETTINGS.fields_by_name['file_prefix']._options = None
  _RAWLOGSSETTINGS.fields_by_name['file_prefix']._serialized_options = b'\212\3101\004<=50'
  _globals['_RAWLOGSSTATUS']._serialized_start=211
  _globals['_RAWLOGSSTATUS']._serialized_end=375
  _globals['_RAWLOGSSETTINGS']._serialized_start=90
  _globals['_RAWLOGSSETTINGS']._serialized_end=208
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.containerregistry.v1 import lifecycle_policy_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2
from yandex.cloud.containerregistry.v1 import lifecycle_policy_service_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class LifecyclePolicyServiceStub(object):
    """A set of methods for managing Lifecycle policy resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Get',
                request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetLifecyclePolicyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2.LifecyclePolicy.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/List',
                request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Create',
                request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.CreateLifecyclePolicyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Update',
                request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.UpdateLifecyclePolicyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Delete',
                request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DeleteLifecyclePolicyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DryRun = channel.unary_unary(
                '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/DryRun',
                request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetDryRunResult = channel.unary_unary(
                '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/GetDryRunResult',
                request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetDryRunLifecyclePolicyResultRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyResult.FromString,
                )
        self.ListDryRunResults = channel.unary_unary(
                '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/ListDryRunResults',
                request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsResponse.FromString,
                )
        self.ListDryRunResultAffectedImages = channel.unary_unary(
                '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/ListDryRunResultAffectedImages',
                request_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesResponse.FromString,
                )


class LifecyclePolicyServiceServicer(object):
    """A set of methods for managing Lifecycle policy resources.
    """

    def Get(self, request, context):
        """Returns the specified lifecycle policy.

        To get the list of all available lifecycle policies, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of lifecycle policies in the specified repository.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a lifecycle policy in the specified repository.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified lifecycle policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified lifecycle policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DryRun(self, request, context):
        """Creates a request of a dry run of the lifecycle policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDryRunResult(self, request, context):
        """Returns the dry run result of the specified lifecycle policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDryRunResults(self, request, context):
        """Retrieves the list of the dry run results.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDryRunResultAffectedImages(self, request, context):
        """Retrieves the list of the affected images.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LifecyclePolicyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetLifecyclePolicyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2.LifecyclePolicy.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.CreateLifecyclePolicyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.UpdateLifecyclePolicyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DeleteLifecyclePolicyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DryRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DryRun,
                    request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetDryRunResult': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDryRunResult,
                    request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetDryRunLifecyclePolicyResultRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyResult.SerializeToString,
            ),
            'ListDryRunResults': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDryRunResults,
                    request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsResponse.SerializeToString,
            ),
            'ListDryRunResultAffectedImages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDryRunResultAffectedImages,
                    request_deserializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.containerregistry.v1.LifecyclePolicyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LifecyclePolicyService(object):
    """A set of methods for managing Lifecycle policy resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Get',
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetLifecyclePolicyRequest.SerializeToString,
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2.LifecyclePolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/List',
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesRequest.SerializeToString,
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListLifecyclePoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Create',
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.CreateLifecyclePolicyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Update',
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.UpdateLifecyclePolicyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/Delete',
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DeleteLifecyclePolicyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DryRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/DryRun',
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDryRunResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/GetDryRunResult',
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.GetDryRunLifecyclePolicyResultRequest.SerializeToString,
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.DryRunLifecyclePolicyResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDryRunResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/ListDryRunResults',
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsRequest.SerializeToString,
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDryRunResultAffectedImages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.containerregistry.v1.LifecyclePolicyService/ListDryRunResultAffectedImages',
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesRequest.SerializeToString,
            yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__service__pb2.ListDryRunLifecyclePolicyResultAffectedImagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/agent/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.agent import status_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/loadtesting/api/v1/agent/agent.proto\x12%yandex.cloud.loadtesting.api.v1.agent\x1a\x32yandex/cloud/loadtesting/api/v1/agent/status.proto\"\xe7\x01\n\x05\x41gent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x05 \x01(\t\x12=\n\x06status\x18\x07 \x01(\x0e\x32-.yandex.cloud.loadtesting.api.v1.agent.Status\x12\x0e\n\x06\x65rrors\x18\x08 \x03(\t\x12\x16\n\x0e\x63urrent_job_id\x18\t \x01(\t\x12\x18\n\x10\x61gent_version_id\x18\n \x01(\tB|\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.agent.agent_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agent'
  _globals['_AGENT']._serialized_start=145
  _globals['_AGENT']._serialized_end=376
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/report_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.loadtesting.api.v1.report.table import report_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_report_dot_table_dot_report__pb2
from yandex.cloud.loadtesting.api.v1.report import status_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_report_dot_status__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/loadtesting/api/v1/report_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x39yandex/cloud/loadtesting/api/v1/report/table/report.proto\x1a\x33yandex/cloud/loadtesting/api/v1/report/status.proto\x1a\x1dyandex/cloud/validation.proto\".\n\x15GetTableReportRequest\x12\x15\n\x07test_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xd6\x02\n\x16GetTableReportResponse\x12>\n\x06status\x18\x01 \x01(\x0e\x32..yandex.cloud.loadtesting.api.v1.report.Status\x12\x45\n\x07overall\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.loadtesting.api.v1.report.table.Report\x12Q\n\x05\x63\x61ses\x18\x03 \x03(\x0b\x32\x42.yandex.cloud.loadtesting.api.v1.GetTableReportResponse.CasesEntry\x1a\x62\n\nCasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.loadtesting.api.v1.report.table.Report:\x02\x38\x01\x32\xc2\x01\n\rReportService\x12\xb0\x01\n\x08GetTable\x12\x36.yandex.cloud.loadtesting.api.v1.GetTableReportRequest\x1a\x37.yandex.cloud.loadtesting.api.v1.GetTableReportResponse\"3\x82\xd3\xe4\x93\x02-\x12+/loadtesting/api/v1/reports/{test_id}/tableBv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.report_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting'
  _GETTABLEREPORTREQUEST.fields_by_name['test_id']._options = None
  _GETTABLEREPORTREQUEST.fields_by_name['test_id']._serialized_options = b'\350\3071\001'
  _GETTABLEREPORTRESPONSE_CASESENTRY._options = None
  _GETTABLEREPORTRESPONSE_CASESENTRY._serialized_options = b'8\001'
  _REPORTSERVICE.methods_by_name['GetTable']._options = None
  _REPORTSERVICE.methods_by_name['GetTable']._serialized_options = b'\202\323\344\223\002-\022+/loadtesting/api/v1/reports/{test_id}/table'
  _globals['_GETTABLEREPORTREQUEST']._serialized_start=262
  _globals['_GETTABLEREPORTREQUEST']._serialized_end=308
  _globals['_GETTABLEREPORTRESPONSE']._serialized_start=311
  _globals['_GETTABLEREPORTRESPONSE']._serialized_end=653
  _globals['_GETTABLEREPORTRESPONSE_CASESENTRY']._serialized_start=555
  _globals['_GETTABLEREPORTRESPONSE_CASESENTRY']._serialized_end=653
  _globals['_REPORTSERVICE']._serialized_start=656
  _globals['_REPORTSERVICE']._serialized_end=850
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/sqlserver/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.sqlserver.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.sqlserver.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.sqlserver.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_database__pb2
from yandex.cloud.mdb.sqlserver.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_user__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2016sp2_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2016sp2__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2017_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2017__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2019_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2019__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/mdb/sqlserver/v1/cluster_service.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/type/timeofday.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a*yandex/cloud/mdb/sqlserver/v1/backup.proto\x1a+yandex/cloud/mdb/sqlserver/v1/cluster.proto\x1a,yandex/cloud/mdb/sqlserver/v1/database.proto\x1a(yandex/cloud/mdb/sqlserver/v1/user.proto\x1a;yandex/cloud/mdb/sqlserver/v1/config/sqlserver2016sp2.proto\x1a\x38yandex/cloud/mdb/sqlserver/v1/config/sqlserver2017.proto\x1a\x38yandex/cloud/mdb/sqlserver/v1/config/sqlserver2019.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"i\n\x14ListClustersResponse\x12\x38\n\x08\x63lusters\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.sqlserver.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb7\x06\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12G\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x32.yandex.cloud.mdb.sqlserver.v1.Cluster.Environment\x12>\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.ConfigSpec\x12\x43\n\x0e\x64\x61tabase_specs\x18\x07 \x03(\x0b\x32+.yandex.cloud.mdb.sqlserver.v1.DatabaseSpec\x12;\n\nuser_specs\x18\x08 \x03(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.UserSpec\x12;\n\nhost_specs\x18\t \x03(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.HostSpec\x12\x1c\n\nnetwork_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x12\x1f\n\x0csqlcollation\x18\r \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x16\n\x0ehost_group_ids\x18\x0e \x03(\t\x12\x1a\n\x12service_account_id\x18\x0f \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x86\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12>\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.ConfigSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xd3\x05\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12$\n\x04name\x18\x04 \x01(\tB\x16\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x06 \x03(\x0b\x32@.yandex.cloud.mdb.sqlserver.v1.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12G\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x32.yandex.cloud.mdb.sqlserver.v1.Cluster.Environment\x12>\n\x0b\x63onfig_spec\x18\x08 \x01(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.ConfigSpec\x12;\n\nhost_specs\x18\t \x03(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.HostSpec\x12\x1c\n\nnetwork_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tfolder_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0c \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\x0e \x03(\t\x12\x1a\n\x12service_account_id\x18\x0f \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"]\n\x1bStartClusterFailoverRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\thost_name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=253\"2\n\x1cStartClusterFailoverMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xb2\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x46\n\x07message\x18\x02 \x03(\x0b\x32\x35.yandex.cloud.mdb.sqlserver.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdd\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12W\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x41.yandex.cloud.mdb.sqlserver.v1.ListClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x08 \x01(\x08\x12\x1a\n\x06\x66ilter\x18\t \x01(\tB\n\x8a\xc8\x31\x06<=1000\"[\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSQLSERVER_ERROR\x10\x01\x12\x19\n\x15SQLSERVER_APPLICATION\x10\x02\"j\n\x17ListClusterLogsResponse\x12\x36\n\x04logs\x18\x01 \x03(\x0b\x32(.yandex.cloud.mdb.sqlserver.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x1aListClusterBackupsResponse\x12\x36\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32%.yandex.cloud.mdb.sqlserver.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"g\n\x18ListClusterHostsResponse\x12\x32\n\x05hosts\x18\x01 \x03(\x0b\x32#.yandex.cloud.mdb.sqlserver.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"D\n\x1aUpdateClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\\\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\"t\n\x0eUpdateHostSpec\x12\x17\n\thost_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\"\x8f\x01\n\x19UpdateClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12P\n\x11update_host_specs\x18\x02 \x03(\x0b\x32-.yandex.cloud.mdb.sqlserver.v1.UpdateHostSpecB\x06\x82\xc8\x31\x02>0\"\xb2\x08\n\nConfigSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x82\x01\n\x1bsqlserver_config_2016sp2std\x18\x02 \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2016sp2stdH\x00R\x1asqlserverConfig_2016sp2std\x12\x82\x01\n\x1bsqlserver_config_2016sp2ent\x18\x05 \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2016sp2entH\x00R\x1asqlserverConfig_2016sp2ent\x12y\n\x18sqlserver_config_2017std\x18\x08 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2017stdH\x00R\x17sqlserverConfig_2017std\x12y\n\x18sqlserver_config_2017ent\x18\t \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2017entH\x00R\x17sqlserverConfig_2017ent\x12y\n\x18sqlserver_config_2019std\x18\n \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019stdH\x00R\x17sqlserverConfig_2019std\x12y\n\x18sqlserver_config_2019ent\x18\x0b \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019entH\x00R\x17sqlserverConfig_2019ent\x12;\n\tresources\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.sqlserver.v1.Resources\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12\x35\n\x06\x61\x63\x63\x65ss\x18\x06 \x01(\x0b\x32%.yandex.cloud.mdb.sqlserver.v1.Access\x12`\n\x15secondary_connections\x18\x07 \x01(\x0e\x32\x41.yandex.cloud.mdb.sqlserver.v1.ClusterConfig.SecondaryConnectionsB\x12\n\x10sqlserver_config2\xc4\x17\n\x0e\x43lusterService\x12\x90\x01\n\x03Get\x12\x30.yandex.cloud.mdb.sqlserver.v1.GetClusterRequest\x1a&.yandex.cloud.mdb.sqlserver.v1.Cluster\"/\x82\xd3\xe4\x93\x02)\x12\'/mdb/sqlserver/v1/clusters/{cluster_id}\x12\x93\x01\n\x04List\x12\x32.yandex.cloud.mdb.sqlserver.v1.ListClustersRequest\x1a\x33.yandex.cloud.mdb.sqlserver.v1.ListClustersResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/mdb/sqlserver/v1/clusters\x12\xab\x01\n\x06\x43reate\x12\x33.yandex.cloud.mdb.sqlserver.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1f\"\x1a/mdb/sqlserver/v1/clusters:\x01*\x12\xb8\x01\n\x06Update\x12\x33.yandex.cloud.mdb.sqlserver.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,2\'/mdb/sqlserver/v1/clusters/{cluster_id}:\x01*\x12\xc3\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.mdb.sqlserver.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/mdb/sqlserver/v1/clusters/{cluster_id}\x12\xb8\x01\n\x05Start\x12\x32.yandex.cloud.mdb.sqlserver.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02/\"-/mdb/sqlserver/v1/clusters/{cluster_id}:start\x12\xb4\x01\n\x04Stop\x12\x31.yandex.cloud.mdb.sqlserver.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02.\",/mdb/sqlserver/v1/clusters/{cluster_id}:stop\x12\xb7\x01\n\x04Move\x12\x31.yandex.cloud.mdb.sqlserver.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\",/mdb/sqlserver/v1/clusters/{cluster_id}:move:\x01*\x12\xbc\x01\n\x06\x42\x61\x63kup\x12\x33.yandex.cloud.mdb.sqlserver.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x30\"./mdb/sqlserver/v1/clusters/{cluster_id}:backup\x12\xb6\x01\n\x07Restore\x12\x34.yandex.cloud.mdb.sqlserver.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\'\"\"/mdb/sqlserver/v1/clusters:restore:\x01*\x12\xdb\x01\n\rStartFailover\x12:.yandex.cloud.mdb.sqlserver.v1.StartClusterFailoverRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*\'\n\x1cStartClusterFailoverMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02:\"5/mdb/sqlserver/v1/clusters/{cluster_id}:startFailover:\x01*\x12\xaf\x01\n\x08ListLogs\x12\x35.yandex.cloud.mdb.sqlserver.v1.ListClusterLogsRequest\x1a\x36.yandex.cloud.mdb.sqlserver.v1.ListClusterLogsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/mdb/sqlserver/v1/clusters/{cluster_id}:logs\x12\xc7\x01\n\x0eListOperations\x12;.yandex.cloud.mdb.sqlserver.v1.ListClusterOperationsRequest\x1a<.yandex.cloud.mdb.sqlserver.v1.ListClusterOperationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/mdb/sqlserver/v1/clusters/{cluster_id}/operations\x12\xbb\x01\n\x0bListBackups\x12\x38.yandex.cloud.mdb.sqlserver.v1.ListClusterBackupsRequest\x1a\x39.yandex.cloud.mdb.sqlserver.v1.ListClusterBackupsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//mdb/sqlserver/v1/clusters/{cluster_id}/backups\x12\xb3\x01\n\tListHosts\x12\x36.yandex.cloud.mdb.sqlserver.v1.ListClusterHostsRequest\x1a\x37.yandex.cloud.mdb.sqlserver.v1.ListClusterHostsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/mdb/sqlserver/v1/clusters/{cluster_id}/hosts\x12\xe7\x01\n\x0bUpdateHosts\x12\x38.yandex.cloud.mdb.sqlserver.v1.UpdateClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*3\n\x1aUpdateClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/hosts:batchUpdate:\x01*Bv\n!yandex.cloud.api.mdb.sqlserver.v1B\x04PSCSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\004PSCSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATECLUSTERREQUEST_LABELSENTRY._options = None
  _CREATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['name']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CREATECLUSTERREQUEST.fields_by_name['description']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['sqlcollation']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['sqlcollation']._serialized_options = b'\212\3101\005<=100'
  _UPDATECLUSTERREQUEST_LABELSENTRY._options = None
  _UPDATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTORECLUSTERREQUEST_LABELSENTRY._options = None
  _RESTORECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST.fields_by_name['time']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['time']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST.fields_by_name['name']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*'
  _RESTORECLUSTERREQUEST.fields_by_name['description']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _RESTORECLUSTERREQUEST.fields_by_name['labels']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _RESTORECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _RESTORECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _STARTCLUSTERFAILOVERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERFAILOVERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTCLUSTERFAILOVERREQUEST.fields_by_name['host_name']._options = None
  _STARTCLUSTERFAILOVERREQUEST.fields_by_name['host_name']._serialized_options = b'\212\3101\005<=253'
  _LOGRECORD_MESSAGEENTRY._options = None
  _LOGRECORD_MESSAGEENTRY._serialized_options = b'8\001'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _HOSTSPEC.fields_by_name['zone_id']._options = None
  _HOSTSPEC.fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _HOSTSPEC.fields_by_name['subnet_id']._options = None
  _HOSTSPEC.fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATEHOSTSPEC.fields_by_name['host_name']._options = None
  _UPDATEHOSTSPEC.fields_by_name['host_name']._serialized_options = b'\350\3071\001'
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['update_host_specs']._options = None
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['update_host_specs']._serialized_options = b'\202\3101\002>0'
  _CLUSTERSERVICE.methods_by_name['Get']._options = None
  _CLUSTERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/mdb/sqlserver/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['List']._options = None
  _CLUSTERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/mdb/sqlserver/v1/clusters'
  _CLUSTERSERVICE.methods_by_name['Create']._options = None
  _CLUSTERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\037\"\032/mdb/sqlserver/v1/clusters:\001*'
  _CLUSTERSERVICE.methods_by_name['Update']._options = None
  _CLUSTERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002,2\'/mdb/sqlserver/v1/clusters/{cluster_id}:\001*'
  _CLUSTERSERVICE.methods_by_name['Delete']._options = None
  _CLUSTERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/mdb/sqlserver/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['Start']._options = None
  _CLUSTERSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\002/\"-/mdb/sqlserver/v1/clusters/{cluster_id}:start'
  _CLUSTERSERVICE.methods_by_name['Stop']._options = None
  _CLUSTERSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\002.\",/mdb/sqlserver/v1/clusters/{cluster_id}:stop'
  _CLUSTERSERVICE.methods_by_name['Move']._options = None
  _CLUSTERSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0021\",/mdb/sqlserver/v1/clusters/{cluster_id}:move:\001*'
  _CLUSTERSERVICE.methods_by_name['Backup']._options = None
  _CLUSTERSERVICE.methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0020\"./mdb/sqlserver/v1/clusters/{cluster_id}:backup'
  _CLUSTERSERVICE.methods_by_name['Restore']._options = None
  _CLUSTERSERVICE.methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002\'\"\"/mdb/sqlserver/v1/clusters:restore:\001*'
  _CLUSTERSERVICE.methods_by_name['StartFailover']._options = None
  _CLUSTERSERVICE.methods_by_name['StartFailover']._serialized_options = b'\262\322*\'\n\034StartClusterFailoverMetadata\022\007Cluster\202\323\344\223\002:\"5/mdb/sqlserver/v1/clusters/{cluster_id}:startFailover:\001*'
  _CLUSTERSERVICE.methods_by_name['ListLogs']._options = None
  _CLUSTERSERVICE.methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\002.\022,/mdb/sqlserver/v1/clusters/{cluster_id}:logs'
  _CLUSTERSERVICE.methods_by_name['ListOperations']._options = None
  _CLUSTERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0024\0222/mdb/sqlserver/v1/clusters/{cluster_id}/operations'
  _CLUSTERSERVICE.methods_by_name['ListBackups']._options = None
  _CLUSTERSERVICE.methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0021\022//mdb/sqlserver/v1/clusters/{cluster_id}/backups'
  _CLUSTERSERVICE.methods_by_name['ListHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\002/\022-/mdb/sqlserver/v1/clusters/{cluster_id}/hosts'
  _CLUSTERSERVICE.methods_by_name['UpdateHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['UpdateHosts']._serialized_options = b'\262\322*3\n\032UpdateClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/hosts:batchUpdate:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=671
  _globals['_GETCLUSTERREQUEST']._serialized_end=724
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=727
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=871
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=873
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=978
  _globals['_CREATECLUSTERREQUEST']._serialized_start=981
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1804
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1759
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1804
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1806
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1849
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1852
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2370
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1759
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1804
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2372
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2415
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2417
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2473
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2475
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2518
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=2520
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=2576
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=2578
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=2621
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=2624
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=3347
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=1759
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=1804
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=3349
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=3412
  _globals['_STARTCLUSTERFAILOVERREQUEST']._serialized_start=3414
  _globals['_STARTCLUSTERFAILOVERREQUEST']._serialized_end=3507
  _globals['_STARTCLUSTERFAILOVERMETADATA']._serialized_start=3509
  _globals['_STARTCLUSTERFAILOVERMETADATA']._serialized_end=3559
  _globals['_LOGRECORD']._serialized_start=3562
  _globals['_LOGRECORD']._serialized_end=3740
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=3694
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=3740
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=3743
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=4220
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=4129
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=4220
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=4222
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=4328
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=4330
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=4456
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=4458
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=4569
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=4571
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=4694
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=4696
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=4805
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=4807
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=4928
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=4930
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=5033
  _globals['_STARTCLUSTERREQUEST']._serialized_start=5035
  _globals['_STARTCLUSTERREQUEST']._serialized_end=5090
  _globals['_STARTCLUSTERMETADATA']._serialized_start=5092
  _globals['_STARTCLUSTERMETADATA']._serialized_end=5134
  _globals['_STOPCLUSTERREQUEST']._serialized_start=5136
  _globals['_STOPCLUSTERREQUEST']._serialized_end=5190
  _globals['_STOPCLUSTERMETADATA']._serialized_start=5192
  _globals['_STOPCLUSTERMETADATA']._serialized_end=5233
  _globals['_MOVECLUSTERREQUEST']._serialized_start=5235
  _globals['_MOVECLUSTERREQUEST']._serialized_end=5334
  _globals['_MOVECLUSTERMETADATA']._serialized_start=5336
  _globals['_MOVECLUSTERMETADATA']._serialized_end=5434
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_start=5436
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_end=5504
  _globals['_HOSTSPEC']._serialized_start=5506
  _globals['_HOSTSPEC']._serialized_end=5598
  _globals['_UPDATEHOSTSPEC']._serialized_start=5600
  _globals['_UPDATEHOSTSPEC']._serialized_end=5716
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_start=5719
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_end=5862
  _globals['_CONFIGSPEC']._serialized_start=5865
  _globals['_CONFIGSPEC']._serialized_end=6939
  _globals['_CLUSTERSERVICE']._serialized_start=6942
  _globals['_CLUSTERSERVICE']._serialized_end=9954
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.iot.broker.v1 import broker_pb2 as yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2
from yandex.cloud.iot.broker.v1 import broker_service_pb2 as yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class BrokerServiceStub(object):
    """A set of methods for managing broker.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/Get',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.GetBrokerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2.Broker.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/List',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokersResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/Create',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.CreateBrokerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/Update',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.UpdateBrokerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/Delete',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.DeleteBrokerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListCertificates = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/ListCertificates',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerCertificatesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerCertificatesResponse.FromString,
                )
        self.AddCertificate = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/AddCertificate',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.AddBrokerCertificateRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteCertificate = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/DeleteCertificate',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.DeleteBrokerCertificateRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListPasswords = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/ListPasswords',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerPasswordsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerPasswordsResponse.FromString,
                )
        self.AddPassword = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/AddPassword',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.AddBrokerPasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeletePassword = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/DeletePassword',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.DeleteBrokerPasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.iot.broker.v1.BrokerService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerOperationsResponse.FromString,
                )


class BrokerServiceServicer(object):
    """A set of methods for managing broker.
    """

    def Get(self, request, context):
        """Returns the specified broker.

        To get the list of available brokers, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of brokers in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a broker in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified broker.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified broker.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCertificates(self, request, context):
        """Retrieves the list of broker certificates for the specified broker.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddCertificate(self, request, context):
        """Adds a certificate.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCertificate(self, request, context):
        """Deletes the specified broker certificate.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPasswords(self, request, context):
        """Retrieves the list of passwords for the specified broker.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPassword(self, request, context):
        """Adds password for the specified broker.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePassword(self, request, context):
        """Deletes the specified password.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified broker.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BrokerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.GetBrokerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2.Broker.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.CreateBrokerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.UpdateBrokerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.DeleteBrokerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListCertificates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCertificates,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerCertificatesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerCertificatesResponse.SerializeToString,
            ),
            'AddCertificate': grpc.unary_unary_rpc_method_handler(
                    servicer.AddCertificate,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.AddBrokerCertificateRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteCertificate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCertificate,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.DeleteBrokerCertificateRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListPasswords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPasswords,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerPasswordsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerPasswordsResponse.SerializeToString,
            ),
            'AddPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPassword,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.AddBrokerPasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeletePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePassword,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.DeleteBrokerPasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.iot.broker.v1.BrokerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BrokerService(object):
    """A set of methods for managing broker.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/Get',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.GetBrokerRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2.Broker.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/List',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokersRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/Create',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.CreateBrokerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/Update',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.UpdateBrokerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/Delete',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.DeleteBrokerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCertificates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/ListCertificates',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerCertificatesRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerCertificatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddCertificate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/AddCertificate',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.AddBrokerCertificateRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCertificate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/DeleteCertificate',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.DeleteBrokerCertificateRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPasswords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/ListPasswords',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerPasswordsRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerPasswordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/AddPassword',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.AddBrokerPasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/DeletePassword',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.DeleteBrokerPasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.broker.v1.BrokerService/ListOperations',
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__service__pb2.ListBrokerOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/config/mongodb5_0.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/mdb/mongodb/v1/config/mongodb5_0.proto\x12\"yandex.cloud.mdb.mongodb.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xfb\n\n\x0fMongodConfig5_0\x12L\n\x07storage\x18\x01 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0.Storage\x12\x63\n\x13operation_profiling\x18\x02 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0.OperationProfiling\x12H\n\x03net\x18\x03 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0.Network\x1a\xa3\x06\n\x07Storage\x12[\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0.Storage.WiredTiger\x12T\n\x07journal\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0.Storage.Journal\x1a\x98\x04\n\nWiredTiger\x12j\n\rengine_config\x18\x01 \x01(\x0b\x32S.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0.Storage.WiredTiger.EngineConfig\x12r\n\x11\x63ollection_config\x18\x02 \x01(\x0b\x32W.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0.Storage.WiredTiger.CollectionConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xe4\x01\n\x10\x43ollectionConfig\x12|\n\x10\x62lock_compressor\x18\x01 \x01(\x0e\x32\x62.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0.Storage.WiredTiger.CollectionConfig.Compressor\"R\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06SNAPPY\x10\x02\x12\x08\n\x04ZLIB\x10\x03\x12\x08\n\x04ZSTD\x10\x04\x1aJ\n\x07Journal\x12?\n\x0f\x63ommit_interval\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-500\x1a\xec\x01\n\x12OperationProfiling\x12Y\n\x04mode\x18\x01 \x01(\x0e\x32K.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\x8c\x07\n\x11MongoCfgConfig5_0\x12N\n\x07storage\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0.Storage\x12\x65\n\x13operation_profiling\x18\x02 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0.OperationProfiling\x12J\n\x03net\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0.Network\x1a\xaa\x02\n\x07Storage\x12]\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0.Storage.WiredTiger\x1a\xbf\x01\n\nWiredTiger\x12l\n\rengine_config\x18\x01 \x01(\x0b\x32U.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0.Storage.WiredTiger.EngineConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xee\x01\n\x12OperationProfiling\x12[\n\x04mode\x18\x01 \x01(\x0e\x32M.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xb3\x01\n\x0fMongosConfig5_0\x12H\n\x03net\x18\x01 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0.Network\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xfa\x01\n\x12MongodConfigSet5_0\x12M\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0\x12H\n\x0buser_config\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0\x12K\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig5_0\"\x82\x02\n\x14MongoCfgConfigSet5_0\x12O\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig5_0\"\xfa\x01\n\x12MongosConfigSet5_0\x12M\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0\x12H\n\x0buser_config\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0\x12K\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig5_0Bx\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mongodb.v1.config.mongodb5_0_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodb'
  _MONGODCONFIG5_0_STORAGE_JOURNAL.fields_by_name['commit_interval']._options = None
  _MONGODCONFIG5_0_STORAGE_JOURNAL.fields_by_name['commit_interval']._serialized_options = b'\372\3071\0051-500'
  _MONGODCONFIG5_0_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._options = None
  _MONGODCONFIG5_0_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._serialized_options = b'\372\3071\002>0'
  _MONGODCONFIG5_0_NETWORK.fields_by_name['max_incoming_connections']._options = None
  _MONGODCONFIG5_0_NETWORK.fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _MONGOCFGCONFIG5_0_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._options = None
  _MONGOCFGCONFIG5_0_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._serialized_options = b'\372\3071\002>0'
  _MONGOCFGCONFIG5_0_NETWORK.fields_by_name['max_incoming_connections']._options = None
  _MONGOCFGCONFIG5_0_NETWORK.fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _MONGOSCONFIG5_0_NETWORK.fields_by_name['max_incoming_connections']._options = None
  _MONGOSCONFIG5_0_NETWORK.fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGODCONFIG5_0']._serialized_start=155
  _globals['_MONGODCONFIG5_0']._serialized_end=1558
  _globals['_MONGODCONFIG5_0_STORAGE']._serialized_start=428
  _globals['_MONGODCONFIG5_0_STORAGE']._serialized_end=1231
  _globals['_MONGODCONFIG5_0_STORAGE_WIREDTIGER']._serialized_start=619
  _globals['_MONGODCONFIG5_0_STORAGE_WIREDTIGER']._serialized_end=1155
  _globals['_MONGODCONFIG5_0_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_start=857
  _globals['_MONGODCONFIG5_0_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_end=924
  _globals['_MONGODCONFIG5_0_STORAGE_WIREDTIGER_COLLECTIONCONFIG']._serialized_start=927
  _globals['_MONGODCONFIG5_0_STORAGE_WIREDTIGER_COLLECTIONCONFIG']._serialized_end=1155
  _globals['_MONGODCONFIG5_0_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR']._serialized_start=1073
  _globals['_MONGODCONFIG5_0_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR']._serialized_end=1155
  _globals['_MONGODCONFIG5_0_STORAGE_JOURNAL']._serialized_start=1157
  _globals['_MONGODCONFIG5_0_STORAGE_JOURNAL']._serialized_end=1231
  _globals['_MONGODCONFIG5_0_OPERATIONPROFILING']._serialized_start=1234
  _globals['_MONGODCONFIG5_0_OPERATIONPROFILING']._serialized_end=1470
  _globals['_MONGODCONFIG5_0_OPERATIONPROFILING_MODE']._serialized_start=1411
  _globals['_MONGODCONFIG5_0_OPERATIONPROFILING_MODE']._serialized_end=1470
  _globals['_MONGODCONFIG5_0_NETWORK']._serialized_start=1472
  _globals['_MONGODCONFIG5_0_NETWORK']._serialized_end=1558
  _globals['_MONGOCFGCONFIG5_0']._serialized_start=1561
  _globals['_MONGOCFGCONFIG5_0']._serialized_end=2469
  _globals['_MONGOCFGCONFIG5_0_STORAGE']._serialized_start=1842
  _globals['_MONGOCFGCONFIG5_0_STORAGE']._serialized_end=2140
  _globals['_MONGOCFGCONFIG5_0_STORAGE_WIREDTIGER']._serialized_start=1949
  _globals['_MONGOCFGCONFIG5_0_STORAGE_WIREDTIGER']._serialized_end=2140
  _globals['_MONGOCFGCONFIG5_0_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_start=857
  _globals['_MONGOCFGCONFIG5_0_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_end=924
  _globals['_MONGOCFGCONFIG5_0_OPERATIONPROFILING']._serialized_start=2143
  _globals['_MONGOCFGCONFIG5_0_OPERATIONPROFILING']._serialized_end=2381
  _globals['_MONGOCFGCONFIG5_0_OPERATIONPROFILING_MODE']._serialized_start=1411
  _globals['_MONGOCFGCONFIG5_0_OPERATIONPROFILING_MODE']._serialized_end=1470
  _globals['_MONGOCFGCONFIG5_0_NETWORK']._serialized_start=1472
  _globals['_MONGOCFGCONFIG5_0_NETWORK']._serialized_end=1558
  _globals['_MONGOSCONFIG5_0']._serialized_start=2472
  _globals['_MONGOSCONFIG5_0']._serialized_end=2651
  _globals['_MONGOSCONFIG5_0_NETWORK']._serialized_start=1472
  _globals['_MONGOSCONFIG5_0_NETWORK']._serialized_end=1558
  _globals['_MONGODCONFIGSET5_0']._serialized_start=2654
  _globals['_MONGODCONFIGSET5_0']._serialized_end=2904
  _globals['_MONGOCFGCONFIGSET5_0']._serialized_start=2907
  _globals['_MONGOCFGCONFIGSET5_0']._serialized_end=3165
  _globals['_MONGOSCONFIGSET5_0']._serialized_start=3168
  _globals['_MONGOSCONFIGSET5_0']._serialized_end=3418
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/target_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/apploadbalancer/v1/target_group.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xb2\x02\n\x0bTargetGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12H\n\x06labels\x18\x05 \x03(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.TargetGroup.LabelsEntry\x12\x38\n\x07targets\x18\x06 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.Target\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x06Target\x12\x14\n\nip_address\x18\x01 \x01(\tH\x00\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\x12\x1c\n\x14private_ipv4_address\x18\x04 \x01(\x08\x42\x14\n\x0c\x61\x64\x64ress_type\x12\x04\xc0\xc1\x31\x01\x42z\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.target_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _TARGETGROUP_LABELSENTRY._options = None
  _TARGETGROUP_LABELSENTRY._serialized_options = b'8\001'
  _TARGET.oneofs_by_name['address_type']._options = None
  _TARGET.oneofs_by_name['address_type']._serialized_options = b'\300\3011\001'
  _globals['_TARGETGROUP']._serialized_start=152
  _globals['_TARGETGROUP']._serialized_end=458
  _globals['_TARGETGROUP_LABELSENTRY']._serialized_start=413
  _globals['_TARGETGROUP_LABELSENTRY']._serialized_end=458
  _globals['_TARGET']._serialized_start=460
  _globals['_TARGET']._serialized_end=561
# @@protoc_insertion_point(module_scope)
